# -*- coding: utf-8 -*-
from setuphelpers import *
import os
from jinja2 import Environment, FileSystemLoader

uninstallkey = []
variables = {
    'thunderbird_config_url': 'https://server/mcd/thunderbird.cfg',
    'thunderbird_config_append_domain': ''
}

# Read local variables file if available
if isfile(makepath(programfiles32,'wapt','private','symetric.txt')) and isfile(makepath(programfiles32,'wapt','private','variables.txt')):
    print('Reading local encrypted variables file')
    from cryptography.fernet import Fernet
    import yaml
    f = Fernet(open(makepath(programfiles32,'wapt','private','symetric.txt'),'r').read())
    variables.update(yaml.safe_load(f.decrypt(open(makepath(programfiles32,'wapt','private','variables.txt'),'r').read())))

def install():
    filecopyto('autoconf.js', makepath(programfiles,'Mozilla Thunderbird','defaults','pref'))
    if not isdir(makepath(programfiles, 'Mozilla Thunderbird','chrome')):
        mkdirs(makepath(programfiles, 'Mozilla Thunderbird','chrome'))
    filecopyto('custom-strings.txt', makepath(programfiles,'Mozilla Thunderbird','chrome'))
    jinja2 = Environment(
        loader=FileSystemLoader(os.getcwd()),
        trim_blocks=True
    )
    open(makepath(programfiles,'Mozilla Thunderbird','thunderbird.cfg'),'w').write(
        jinja2.get_template('thunderbird.cfg.j2').render(
            thunderbird_config_url = variables['thunderbird_config_url'],
            thunderbird_config_append_domain = variables['thunderbird_config_append_domain']
        )
    )

def uninstall():
    remove_file(makepath(programfiles,'Mozilla Thunderbird','defaults','pref','autoconf.js'))
    remove_file(makepath(programfiles,'Mozilla Thunderbird','chrome','custom-strings.txt'))
    remove_file(makepath(programfiles,'Mozilla Thunderbird','thunderbird.cfg'))

def audit():
    if (
            not isfile(makepath(programfiles,'Mozilla Thunderbird','defaults','pref','autoconf.js')) or
            not isfile(makepath(programfiles,'Mozilla Thunderbird','chrome','custom-strings.txt')) or
            not isfile(makepath(programfiles,'Mozilla Thunderbird','thunderbird.cfg'))
        ):
        print('At least one config file is missing')
        return "ERROR"
    return "OK"